@@ -1,7 +1,7 @@
 package App::SahUtils;
 
-our $DATE = '2016-12-09'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2017-03-09'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -346,7 +346,7 @@ App::SahUtils - Collection of CLI utilities for Sah and Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.41 of App::SahUtils (from Perl distribution App-SahUtils), released on 2016-12-09.
+This document describes version 0.42 of App::SahUtils (from Perl distribution App-SahUtils), released on 2017-03-09.
 
 =head1 SYNOPSIS
 
@@ -406,7 +406,11 @@ L<Sah> and L<Data::Sah>:
 =head1 FUNCTIONS
 
 
-=head2 get_sah_type(%args) -> [status, msg, result, meta]
+=head2 get_sah_type
+
+Usage:
+
+ get_sah_type(%args) -> [status, msg, result, meta]
 
 Extract type from a Sah string or array schema.
 
@@ -435,7 +439,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_builtin_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_builtin_type
+
+Usage:
+
+ is_sah_builtin_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a Sah builtin type.
 
@@ -464,7 +472,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_collection_builtin_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_collection_builtin_type
+
+Usage:
+
+ is_sah_collection_builtin_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a Sah collection builtin type.
 
@@ -493,7 +505,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_collection_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_collection_type
+
+Usage:
+
+ is_sah_collection_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a collection Sah type.
 
@@ -523,7 +539,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_numeric_builtin_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_numeric_builtin_type
+
+Usage:
+
+ is_sah_numeric_builtin_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a Sah numeric builtin type.
 
@@ -552,7 +572,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_numeric_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_numeric_type
+
+Usage:
+
+ is_sah_numeric_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a numeric Sah type.
 
@@ -582,7 +606,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_ref_builtin_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_ref_builtin_type
+
+Usage:
+
+ is_sah_ref_builtin_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a Sah ref builtin type.
 
@@ -611,7 +639,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_ref_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_ref_type
+
+Usage:
+
+ is_sah_ref_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a ref Sah type.
 
@@ -641,7 +673,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_simple_builtin_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_simple_builtin_type
+
+Usage:
+
+ is_sah_simple_builtin_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a Sah simple builtin type.
 
@@ -670,7 +706,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_simple_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_simple_type
+
+Usage:
+
+ is_sah_simple_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a simple Sah type.
 
@@ -700,7 +740,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 is_sah_type(%args) -> [status, msg, result, meta]
+=head2 is_sah_type
+
+Usage:
+
+ is_sah_type(%args) -> [status, msg, result, meta]
 
 Check that a string or array schema is a Sah type.
 
@@ -755,7 +799,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
